About — CEMENTO 0.14.1 documentation

Skip to main content
`Ctrl`+`K`

# About

CEMENTO is a component python package of the larger SDLE FAIR application suite of tools for creating scientific ontologies more efficiently. This package provides functional interfaces for converting draw.io diagrams of ontologies into RDF triple file formats and vice versa. This package is able to provide term matching between reference ontology files and terms used in draw.io diagrams allowing for faster ontology deployment while maintaining robust cross-references.

CEMENTO stands for the Centralized Entity Mapping & Extraction Nexus for Triples and Ontologies – a mouthful for an acronym, but an important metaphor for the package building the road to ontologies for materials data.

## Package Contributors

Name | Affiliation | Role | Material Contribution
--- | --- | --- | ---
Gabriel Obsequio Ponon | MDS3 Center of Excellence, Case Western Reserve University; Advanced Photon Source, Argonne National Laboratory | Lead Developer and Maintaner | Authored current package. Conceptualized package and current package features. Actively performs bug fixes and package optimization.
Priyan Rajamohan | MDS3 Center of Excellence, Case Western Reserve University | Software and Idea Contributor | Conceptualized package and feature set to fit client needs.
Ethan Frakes | MDS3 Center of Excellence, Case Western Reserve University; University of Central Florida | Software Tester and Contributor | Identifies and implements solutions for critical bugs related to function, usability and security.
Jayvic Cristian Jimenez | Lawrence Livermore National Laboratory | Software Tester and Idea Contributor | Provided crucial insights for idea development and refinement of the approach. Prototypes package with real datasets.
Hemant Sharma | Advanced Photon Source, Argonne National Laboratory | Research Supervisor and Idea Contributor | Oversaw and contributed to idea development, iteration, and package creation. Provided impetus for the package and drove adoption at the APS.
Roger French | MDS3 Center of Excellence, Case Western Reserve University | Research Supervisor | Oversaw integration of package into existing semantic data management frameworks at CWRU-SDLE.

## Cite this work!

Please make sure to cite us when you use our software for your publications. We are a team of researchers building tools for fellow researchers and we appreciate the support. Cite us through the following:

IEEE

    G. O. Ponon, B. P. Rajamohan, E. Frakes, J. Jimenez, H. Sharma, and R. H. French, cemento: A package to view and write ontologies directly from draw.io diagram files. (Jul. 27, 2025). Python. Accessed: Jul. 28, 2025. [OS Independent]. Available: https://github.com/cwru-sdle/CEMENTO

Nature

    Ponon, G. O., Rajamohan, B. P., Frakes E., Jimenez, J., Sharma, H. & French, R. H. cemento: A package to view and write ontologies directly from draw.io diagram files. (2025).

APA 7th

    Ponon, G. O., Rajamohan, B. P., Frakes E., Jimenez, J., Sharma, H., & French, R. H. (2025). cemento: A package to view and write ontologies directly from draw.io diagram files. (Version 0.14.1) [Python; OS Independent]. https://github.com/cwru-sdle/CEMENTO

Chicago 18th

    Ponon, Gabriel O., Balashanmuga Priyan Rajamohan, Ethan Frakes, Jayvic Cristian Jimenez, Hemant Sharma, and Roger H. French. Cemento: A Package to View and Write Ontologies Directly from Draw.Io Diagram Files. Python. Version 0.14.1. Released July 27, 2025. OS Independent. https://github.com/cwru-sdle/CEMENTO.

Here are the files if you prefer `BibTex` or `Zotero RDF`.

## Project License

3-Clause BSD License

Copyright 2025 CWRU SDLE-MDS3

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS “AS IS” AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Third Party Licenses

For information about third-party licenses for packages used in this project, please refer to the THIRD_PARTY_LICENSES.txt file in the repository or the Licenses Page on the documentation.

## Acknowledgements

This work is based upon research in the Materials Data Science for Stockpile Stewardship Center of Excellence (MDS3-COE), and supported by the U.S. Department of Energy’s National Nuclear Security Administration under Award Number(s) DE-NA0004104. This work was also supported in part by the U.S. Department of Energy, Office of Science, Office of Workforce Development for Teachers and Scientists (WDTS).